==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/TileGeneratorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
var TileGeneratorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(TileGeneratorDescriptionMetadata, _super);
    function TileGeneratorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TileGeneratorDescriptionMetadata.b = function (a) {
        if (TileGeneratorDescriptionMetadata.a == null) {
            TileGeneratorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TileGeneratorDescriptionMetadata.c(TileGeneratorDescriptionMetadata.a);
        }
        if (a.j(TileGeneratorDescriptionMetadata.a)) {
            return;
        }
        a.y(TileGeneratorDescriptionMetadata.a);
    };
    TileGeneratorDescriptionMetadata.c = function (a) {
    };
    TileGeneratorDescriptionMetadata.d = function (a) {
        TileGeneratorDescriptionMetadata.b(a);
        a.z("TileGenerator", TileGeneratorDescriptionMetadata.a);
    };
    TileGeneratorDescriptionMetadata.$t = markType(TileGeneratorDescriptionMetadata, 'TileGeneratorDescriptionMetadata');
    TileGeneratorDescriptionMetadata.a = null;
    return TileGeneratorDescriptionMetadata;
}(Base));
export { TileGeneratorDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/TileGeneratorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
var TileGeneratorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(TileGeneratorDescriptionMetadata, _super);
    function TileGeneratorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TileGeneratorDescriptionMetadata.b = function (a) {
        if (TileGeneratorDescriptionMetadata.a == null) {
            TileGeneratorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TileGeneratorDescriptionMetadata.c(TileGeneratorDescriptionMetadata.a);
        }
        if (a.k(TileGeneratorDescriptionMetadata.a)) {
            return;
        }
        a.aa(TileGeneratorDescriptionMetadata.a);
    };
    TileGeneratorDescriptionMetadata.c = function (a) {
    };
    TileGeneratorDescriptionMetadata.d = function (a) {
        TileGeneratorDescriptionMetadata.b(a);
        a.ab("TileGenerator", TileGeneratorDescriptionMetadata.a);
    };
    TileGeneratorDescriptionMetadata.$t = markType(TileGeneratorDescriptionMetadata, 'TileGeneratorDescriptionMetadata');
    TileGeneratorDescriptionMetadata.a = null;
    return TileGeneratorDescriptionMetadata;
}(Base));
export { TileGeneratorDescriptionMetadata };
